#ifndef NT2_INCLUDE_FUNCTIONS_ROUND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ROUND_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/round.hpp>

#endif
